@@ -86,7 +86,7 @@ impl std::ops::Div<f64> for UVW {
 }
 
 #[cfg(test)]
-use crate::approx::AbsDiffEq;
+use approx::AbsDiffEq;
 
 #[cfg(test)]
 impl AbsDiffEq for UVW {
@@ -106,7 +106,7 @@ impl AbsDiffEq for UVW {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::approx::assert_abs_diff_eq;
+    use approx::assert_abs_diff_eq;
 
     #[test]
     fn test_uvw_mul() {
